@@ -1,12 +1,12 @@
 # Copyright: Damien Elmes <anki@ichi2.net>
 # License: GNU GPL, version 3 or later; http://www.gnu.org/copyleft/gpl.html
 
-import os, sys, optparse, re
+import os, sys, shutil
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 appName="Anki"
-appVersion="0.9.9.6"
+appVersion="0.9.9.7.9"
 appWebsite="http://ichi2.net/anki/download/"
 appWiki="http://ichi2.net/anki/wiki/"
 appHelpSite="http://ichi2.net/anki/wiki/AnkiWiki"
@@ -29,22 +29,77 @@ sys.path.append(os.path.dirname(__file__))
 # App initialisation
 ##########################################################################
 
+class SplashScreen(object):
+
+    def __init__(self, max=100):
+        self.pixmap = QPixmap(":/icons/anki-logo.png")
+        self.splash = QSplashScreen(self.pixmap)
+        self.prog = QProgressBar(self.splash)
+        self.prog.setMaximum(max)
+        if QApplication.instance().style().objectName() != "plastique":
+            self.style = QStyleFactory.create("plastique")
+            self.prog.setStyle(self.style)
+        self.prog.setStyleSheet("""* {
+color: #ffffff;
+background-color: #061824;
+margin:0px;
+border:0px;
+padding: 0px;
+text-align: center;}
+*::chunk {
+color: #13486c;
+}
+""")
+        x = 8
+        self.prog.setGeometry(self.splash.width()/10, 8.85*self.splash.height()/10,
+                                x*self.splash.width()/10, self.splash.height()/10)
+        self.splash.show()
+        self.val = 1
+
+    def update(self):
+        self.prog.setValue(self.val)
+        self.val += 1
+        QApplication.instance().processEvents()
+
+    def finish(self, obj):
+        self.splash.finish(obj)
+
+class AnkiApp(QApplication):
+
+    def event(self, evt):
+        from anki.hooks import runHook
+        if evt.type() == QEvent.FileOpen:
+            runHook("macLoadEvent", unicode(evt.file()))
+            return True
+        return QApplication.event(self, evt)
+
 def run():
-    import forms
     import config
-    import ui
-    # put anki home in c:\anki on win32 if not available
+
+    # home on win32 is broken
     if sys.platform == "win32":
-        path = os.path.expanduser("~")
-        if path[0] == "~" or not os.access(path, os.R_OK | os.W_OK):
+        if 'APPDATA' in os.environ:
+            oldConf = os.path.expanduser("~/.anki/config.db")
+            oldPlugins = os.path.expanduser("~/.anki/plugins")
+            os.environ['HOME'] = os.environ['APPDATA']
+        else:
+            oldConf = None
             os.environ['HOME'] = "c:\\anki"
+        try:
+            os.makedirs(os.path.expanduser("~/.anki"))
+        except:
+            pass
+        if os.path.exists(oldConf) and not os.path.exists(oldConf.replace(
+            "config.db", "config.db.old")):
             try:
-                os.mkdir("c:\\anki")
-            except OSError:
+                shutil.copy2(oldConf,
+                             os.path.expanduser("~/.anki/config.db"))
+                shutil.copytree(oldPlugins,
+                             os.path.expanduser("~/.anki/plugins"))
+            except:
                 pass
-
-    app = QApplication(sys.argv)
-
+            os.rename(oldConf, oldConf.replace("config.db",
+                                               "config.db.old"))
     # setup paths for forms, icons
     sys.path.append(modDir)
     # jpeg module
@@ -55,14 +110,23 @@ def run():
     else:
         QCoreApplication.addLibraryPath(runningDir)
 
+    app = AnkiApp(sys.argv)
+    QCoreApplication.setApplicationName("Anki")
+
+    import forms
+    import ui
+
+    ui.splash = SplashScreen(5)
+
     import anki
     if anki.version != appVersion:
         print "You have libanki %s, but this is ankiqt %s" % (
             anki.version, appVersion)
-        print "\nPlease install the latest libanki."
+        print "\nPlease ensure versions match."
         return
 
     # parse args
+    import optparse
     parser = optparse.OptionParser()
     parser.usage = "%prog [<deck.anki>]"
     parser.add_option("-c", "--config", help="path to config dir",
@@ -100,6 +164,8 @@ def run():
     # load main window
     ui.importAll()
     ui.dialogs.registerDialogs()
+    ui.splash.update()
+
     mw = ui.main.AnkiQt(app, conf, args)
     try:
         styleFile = open(os.path.join(opts.config, "style.css"))
@@ -109,5 +175,8 @@ def run():
 
     app.exec_()
 
+    # ensure we kill any other threads
+    sys.exit(0)
+
 if __name__ == "__main__":
     run()
